from kubragen.consts import PROVIDER_DIGITALOCEAN, \
    PROVIDERSVC_DIGITALOCEAN_KUBERNETES
from kubragen.provider import Provider


class ProviderDigitalOceanKubernetes(Provider):
    """
    Provider for DigitalOcean Kubernetes.
    """
    def __init__(self):
        super().__init__(PROVIDER_DIGITALOCEAN, PROVIDERSVC_DIGITALOCEAN_KUBERNETES)



from kubragen.consts import PROVIDERSVC_GENERIC, PROVIDER_KIND
from kubragen.provider import Provider


class ProviderKINDGeneric(Provider):
    """
    Provider for KIND.
    """
    def __init__(self):
        super().__init__(PROVIDER_KIND, PROVIDERSVC_GENERIC)



from kubragen.consts import PROVIDER_AMAZON, PROVIDERSVC_AMAZON_EKS
from kubragen.provider import Provider


class ProviderAmazonEKS(Provider):
    """
    Provider for Amazon EKS.
    """
    def __init__(self):
        super().__init__(PROVIDER_AMAZON, PROVIDERSVC_AMAZON_EKS)



from kubragen.consts import PROVIDER_K3D, PROVIDERSVC_GENERIC
from kubragen.provider import Provider


class ProviderK3DGeneric(Provider):
    """
    Provider for K3D.
    """
    def __init__(self):
        super().__init__(PROVIDER_K3D, PROVIDERSVC_GENERIC)



from kubragen.consts import PROVIDER_GOOGLE, PROVIDERSVC_GOOGLE_GKE
from kubragen.provider import Provider


class ProviderGoogleGKE(Provider):
    """
    Provider for Google GKE.
    """
    def __init__(self):
        super().__init__(PROVIDER_GOOGLE, PROVIDERSVC_GOOGLE_GKE)
